<?php
namespace App;

use DI\ContainerBuilder;
use Interop\Container\ContainerInterface;

class App extends \DI\Bridge\Slim\App {

    protected function configureContainer(ContainerBuilder $builder)
    {
        $definitions = [
            'settings.displayErrorDetails' => true,
            
            'errorHandler' => function ($c) {
                return function ($request, $response, $e) use ($c) {
                    return $response->withStatus(500)->withJson([
                        'error'   => true,
                        'message' => $e->getMessage(),
                        'result'  => []
                    ]);
                };
            },

            \Doctrine\DBAL\Connection::class => function () {
                
                global $ENVIRONMENT_FILE;

                $environmentFile = $ENVIRONMENT_FILE;
                $environment     = json_decode($environmentFile, true);

                $connection = null;

                $myPlatform = new \Doctrine\DBAL\Platforms\SQLServerPlatform();

                $connection = \Doctrine\DBAL\DriverManager::getConnection(array(
                    'user'        => $environment['user'],
                    'password'    => $environment['password'],
                    'host'        => $environment['host'],
                    'dbname'      => $environment['dbname'],
                    'driver'      => 'sqlsrv',
                    'charset'     => 'UTF-8',
                    'platform'    => $myPlatform,
                ), $config = new \Doctrine\DBAL\Configuration);

                // $connection->executeQuery("SET DATEFORMAT dmy;");
                return $connection;
            }
        ];

        $builder->addDefinitions($definitions);
    }
}
